#include "pushbut.hpp"

PushButton::PushButton(int x, int y,
		 		   char* plegend, 
				   int* initial_state, 
				   void (*activate)() ) :
	Icon(x, y, 
		x + PUSH_BUTTON_WIDTH, 
		y + PUSH_BUTTON_HEIGHT)
{
	// save reference to the buttons's control variable
	state = initial_state;

	// also save the reference the application
	// program's function that will be invoked
	// when the button is used
	activation_function = activate;

	// record all the button colors
	shade_color = BLACK;
	border_color = BRIGHT_GREEN;
        inactive_color = CYAN;
	active_color = BRIGHT_CYAN;
	legend_color = BLUE;

	// set the initial color for the button
	fill_color = inactive_color;

	// record the button's legend
	SetLegend(plegend);

	// create the backdrop box
	box = new ShadedBox(x1, y1,
			     x2 - x1, y2 - y1,
			     shade_color,
			     border_color,
			     fill_color);
}

void PushButton::Display()
{
	if (*state)
	    fill_color = active_color;
	  else
	    fill_color = inactive_color;

	// show the backdop box
	box->Color(fill_color);
	box->Display();

	// display the push button legend
	BOX_TYPE box;
	box.x1 = x1;
	box.y1 = y1;
	box.x2 = x2;
	box.y2 = y2;
	Legend title_legend;
	title_legend.Center(&box, legend_color, legend);
}

void PushButton::Activate()
{
	// see if the button has an application
	// function to call, and invoke it if so
	if (activation_function)
	  (*activation_function)();
}

PushButton::~PushButton()
{
	delete box;
}




BistablePushButton::BistablePushButton(int x, int y,
    char *legend, int* initial_state, void (*activate)() ) :
		 PushButton(x, y, legend, initial_state, activate)
{}


void BistablePushButton::LeftButtonPressed()
{
	// toggle the button's state

	if (*state == 0) {
	  // switch button to ON state
	  *state = 1;
	  fill_color = active_color;
	}

	else {
	  // switch button to OFF state
	  *state = 0;
	  fill_color = inactive_color;
	}

	// change the button's color
	box->Color(fill_color);
	Display();

	// invoke the application program
	// to handle the button command
	Activate();
}


MonostablePushButton::MonostablePushButton(int x, int y,
  char *legend, int* initial_state,  void (*activate)() ) :
	PushButton(x, y, legend, initial_state, activate)
{}


void MonostablePushButton::LeftButtonPressed()
{
	// turn button ON
	*state = 1;
	fill_color = active_color;

	// show new button color
	box->Color(fill_color);
	Display();

	// invoke the application program
	// to handle the button command
	Activate();
}

void MonostablePushButton::LeftButtonReleased()
{
	// turn button OFF
	*state = 0;
	fill_color = inactive_color;

	// show new button color
	box->Color(fill_color);
	Display();

	// invoke the application program
	// to handle the button command
	Activate();
}
